@@ -27,14 +27,14 @@
 #include "k3bthroughputestimator.h"
 #include "k3bglobalsettings.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QRegExp>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QString>
+#include <QStringList>
+#include <QRegExp>
+#include <QFile>
 #include "k3b_i18n.h"
 
-#include <QtCore/QTemporaryFile>
+#include <QTemporaryFile>
 
 
 Q_DECLARE_METATYPE( QProcess::ExitStatus )
@@ -263,7 +263,7 @@ bool K3b::CdrskinWriter::prepareProcess()
             d->process << "-tao";
 #ifdef K3B_DEBUG
         qDebug() << "DEBUG:" << __PRETTY_FUNCTION__ << "K3B user get *NO* "
-            "opportunity via UI to explicitely choose SAO/DAO" <<
+            "opportunity via UI to explicitly choose SAO/DAO" <<
             "let libburn choose the write type according to other parameters "
             "and the medium state.";
 #endif
