@@ -29,9 +29,9 @@
 #include "k3bvolumenamewidget.h"
 
 #include <KLocalizedString>
-#include <KIOWidgets/KFileItemDelegate>
-#include <KIOWidgets/KRun>
-#include <KXmlGui/KActionCollection>
+#include <KFileItemDelegate>
+#include <KRun>
+#include <KActionCollection>
 
 #include <QSortFilterProxyModel>
 #include <QAction>
@@ -55,7 +55,7 @@ public:
     }
 
 protected:
-    virtual QWidget* createWidget( QWidget* parent )
+    QWidget* createWidget( QWidget* parent ) override
     {
         return new K3b::VolumeNameWidget( m_doc, parent );
     }
@@ -295,7 +295,8 @@ void K3b::DataViewImpl::slotOpen()
                                     item->mimeType().name() ) ) {
             KRun::runUrl( url,
                         item->mimeType().name(),
-                        m_view );
+                        m_view,
+                        KRun::RunFlags());
         }
         else {
             KRun::displayOpenWithDialog( QList<QUrl>() << url, m_view );
